@@ -181,6 +181,7 @@ def chunk_file(fn, chunk_size, use_b64=True, encoding='utf-8'):
         chunk_bytes = file_dat[0:chunk_size]
         file_dat = file_dat[chunk_size:]
         dat = {
+            'time': time.time(),
             'chunk': chunk_bytes,
             'part': f'{part}.{total_parts}',
             'filename': fn,
@@ -334,7 +335,7 @@ class kafka_mdml_producer:
             'value.serializer': json_serializer
         }
         self.producer = SerializingProducer(producer_config)
-    def produce(self, data, key="key"):
+    def produce(self, data, key=None):
         """
         Produce data to the supplied topic 
 
@@ -343,7 +344,7 @@ class kafka_mdml_producer:
         data : dict
             Dictionary of the data
         """
-        self.producer.produce(topic = self.topic, key=key, value=data)
+        self.producer.produce(topic=self.topic, key=key, value=data)
     def flush(self):
         """
         Flush (send) any messages currently waiting in the producer.
@@ -488,6 +489,8 @@ class kafka_mdml_consumer:
                         'parts': part_info[1],
                         part_info[0]: value['chunk'] 
                     }
+                if part_info == 1:
+                    files[fn]['time'] = value['time']
                 if len(files[fn].keys()) == (int(files[fn]['parts']) + 1):
                     dat = ''
                     for i in range(int(files[fn]['parts'])):
@@ -505,9 +508,10 @@ class kafka_mdml_consumer:
                             with open(f'{save_dir}/{os.path.basename(fn)}', 'w', encoding=value['encoding']) as f:
                                 f.write(dat)
                         else:
-                            ret = dat.decode(value['encoding'])                       
+                            ret = dat.decode(value['encoding'])                     
+                    timestamp = files[fn]['time']
                     del files[fn]
-                    yield ret
+                    yield timestamp, ret
             except KeyboardInterrupt:
                 break
 
